@@ -5,42 +5,80 @@ extern crate env_logger;
 extern crate log;
 
 use clap::{App, AppSettings, Arg, ArgMatches};
-use rustpython_compiler::{compile, error::CompileError, error::CompileErrorType};
-use rustpython_parser::error::ParseErrorType;
+use rustpython_compiler::compile;
 use rustpython_vm::{
-    import, print_exception,
-    pyobject::{ItemProtocol, PyObjectRef, PyResult},
+    exceptions::print_exception,
+    match_class,
+    obj::{objint::PyInt, objtype},
+    pyobject::{ItemProtocol, PyResult},
     scope::Scope,
-    util, PySettings, VirtualMachine,
+    util, InitParameter, PySettings, VirtualMachine,
 };
-use std::convert::TryInto;
 
+use std::convert::TryInto;
 use std::env;
 use std::path::PathBuf;
 use std::process;
 use std::str::FromStr;
 
+mod shell;
+
 fn main() {
     #[cfg(feature = "flame-it")]
     let main_guard = flame::start_guard("RustPython main");
     env_logger::init();
     let app = App::new("RustPython");
     let matches = parse_arguments(app);
-    let settings = create_settings(&matches);
+    let mut settings = create_settings(&matches);
+
+    // We only include the standard library bytecode in WASI when initializing
+    if cfg!(target_os = "wasi") {
+        settings.initialization_parameter = InitParameter::InitializeInternal;
+    }
+
     let vm = VirtualMachine::new(settings);
 
     let res = run_rustpython(&vm, &matches);
-    // See if any exception leaked out:
-    handle_exception(&vm, res);
 
     #[cfg(feature = "flame-it")]
     {
         main_guard.end();
         if let Err(e) = write_profile(&matches) {
             error!("Error writing profile information: {}", e);
-            process::exit(1);
         }
     }
+
+    // See if any exception leaked out:
+    if let Err(err) = res {
+        if objtype::isinstance(&err, &vm.ctx.exceptions.system_exit) {
+            let args = err.args();
+            match args.as_slice().len() {
+                0 => return,
+                1 => match_class!(match args.as_slice()[0].clone() {
+                    i @ PyInt => {
+                        use num_traits::cast::ToPrimitive;
+                        process::exit(i.as_bigint().to_i32().unwrap_or(0));
+                    }
+                    arg => {
+                        if vm.is_none(&arg) {
+                            return;
+                        }
+                        if let Ok(s) = vm.to_str(&arg) {
+                            println!("{}", s);
+                        }
+                    }
+                }),
+                _ => {
+                    if let Ok(r) = vm.to_repr(args.as_object()) {
+                        println!("{}", r);
+                    }
+                }
+            }
+        } else {
+            print_exception(&vm, &err);
+        }
+        process::exit(1);
+    }
 }
 
 fn parse_arguments<'a>(app: App<'a, '_>) -> ArgMatches<'a> {
@@ -148,9 +186,19 @@ fn create_settings(matches: &ArgMatches) -> PySettings {
     // add the current directory to sys.path
     settings.path_list.push("".to_owned());
 
+    if let Some(paths) = option_env!("BUILDTIME_RUSTPYTHONPATH") {
+        settings.path_list.extend(
+            std::env::split_paths(paths).map(|path| path.into_os_string().into_string().unwrap()),
+        )
+    } else if option_env!("RUSTPYTHONPATH").is_none() {
+        settings
+            .path_list
+            .push(concat!(env!("CARGO_MANIFEST_DIR"), "/Lib").to_owned());
+    }
+
     if !ignore_environment {
-        settings.path_list.append(&mut get_paths("RUSTPYTHONPATH"));
-        settings.path_list.append(&mut get_paths("PYTHONPATH"));
+        settings.path_list.extend(get_paths("RUSTPYTHONPATH"));
+        settings.path_list.extend(get_paths("PYTHONPATH"));
     }
 
     // Now process command line flags:
@@ -210,7 +258,7 @@ fn create_settings(matches: &ArgMatches) -> PySettings {
             .chain(cmd.skip(1).map(ToOwned::to_owned))
             .collect()
     } else {
-        vec![]
+        vec!["".to_owned()]
     };
 
     settings.argv = argv;
@@ -230,23 +278,23 @@ fn get_env_var_value(name: &str) -> Result<u8, std::env::VarError> {
 }
 
 /// Helper function to retrieve a sequence of paths from an environment variable.
-fn get_paths(env_variable_name: &str) -> Vec<String> {
-    let paths = env::var_os(env_variable_name);
-    match paths {
-        Some(paths) => env::split_paths(&paths)
-            .map(|path| {
-                path.into_os_string()
-                    .into_string()
-                    .unwrap_or_else(|_| panic!("{} isn't valid unicode", env_variable_name))
-            })
-            .collect(),
-        None => vec![],
-    }
+fn get_paths(env_variable_name: &str) -> impl Iterator<Item = String> + '_ {
+    env::var_os(env_variable_name)
+        .into_iter()
+        .flat_map(move |paths| {
+            env::split_paths(&paths)
+                .map(|path| {
+                    path.into_os_string()
+                        .into_string()
+                        .unwrap_or_else(|_| panic!("{} isn't valid unicode", env_variable_name))
+                })
+                .collect::<Vec<_>>()
+        })
 }
 
 #[cfg(feature = "flame-it")]
 fn write_profile(matches: &ArgMatches) -> Result<(), Box<dyn std::error::Error>> {
-    use std::fs::File;
+    use std::{fs, io};
 
     enum ProfileFormat {
         Html,
@@ -273,12 +321,14 @@ fn write_profile(matches: &ArgMatches) -> Result<(), Box<dyn std::error::Error>>
         ProfileFormat::Speedscope => "flamescope.json".as_ref(),
     });
 
-    let profile_output: Box<dyn std::io::Write> = if profile_output == "-" {
-        Box::new(std::io::stdout())
+    let profile_output: Box<dyn io::Write> = if profile_output == "-" {
+        Box::new(io::stdout())
     } else {
-        Box::new(File::create(profile_output)?)
+        Box::new(fs::File::create(profile_output)?)
     };
 
+    let profile_output = io::BufWriter::new(profile_output);
+
     match profile_format {
         ProfileFormat::Html => flame::dump_html(profile_output)?,
         ProfileFormat::Text => flame::dump_text_to_writer(profile_output)?,
@@ -289,26 +339,6 @@ fn write_profile(matches: &ArgMatches) -> Result<(), Box<dyn std::error::Error>>
 }
 
 fn run_rustpython(vm: &VirtualMachine, matches: &ArgMatches) -> PyResult<()> {
-    import::init_importlib(&vm, true)?;
-
-    if let Some(paths) = option_env!("BUILDTIME_RUSTPYTHONPATH") {
-        let sys_path = vm.get_attribute(vm.sys_module.clone(), "path")?;
-        for (i, path) in std::env::split_paths(paths).enumerate() {
-            vm.call_method(
-                &sys_path,
-                "insert",
-                vec![
-                    vm.ctx.new_int(i),
-                    vm.ctx.new_str(
-                        path.into_os_string()
-                            .into_string()
-                            .expect("Invalid UTF8 in BUILDTIME_RUSTPYTHONPATH"),
-                    ),
-                ],
-            )?;
-        }
-    }
-
     let scope = vm.new_scope_with_builtins();
     let main_module = vm.new_module("__main__", scope.globals.clone());
 
@@ -326,13 +356,20 @@ fn run_rustpython(vm: &VirtualMachine, matches: &ArgMatches) -> PyResult<()> {
 
     // Figure out if a -c option was given:
     if let Some(command) = matches.value_of("c") {
-        run_command(&vm, scope, command.to_string())?;
+        run_command(&vm, scope, command.to_owned())?;
     } else if let Some(module) = matches.value_of("m") {
         run_module(&vm, module)?;
     } else if let Some(filename) = matches.value_of("script") {
-        run_script(&vm, scope, filename)?
+        run_script(&vm, scope.clone(), filename)?;
+        if matches.is_present("inspect") {
+            shell::run_shell(&vm, scope)?;
+        }
     } else {
-        run_shell(&vm, scope)?;
+        println!(
+            "Welcome to the magnificent Rust Python {} interpreter \u{1f631} \u{1f596}",
+            crate_version!()
+        );
+        shell::run_shell(&vm, scope)?;
     }
 
     Ok(())
@@ -349,16 +386,9 @@ fn _run_string(vm: &VirtualMachine, scope: Scope, source: &str, source_path: Str
     vm.run_code_obj(code_obj, scope)
 }
 
-fn handle_exception<T>(vm: &VirtualMachine, result: PyResult<T>) {
-    if let Err(err) = result {
-        print_exception(vm, &err);
-        process::exit(1);
-    }
-}
-
 fn run_command(vm: &VirtualMachine, scope: Scope, source: String) -> PyResult<()> {
     debug!("Running command {}", source);
-    _run_string(vm, scope, &source, "<stdin>".to_string())?;
+    _run_string(vm, scope, &source, "<stdin>".to_owned())?;
     Ok(())
 }
 
@@ -395,13 +425,13 @@ fn run_script(vm: &VirtualMachine, scope: Scope, script_file: &str) -> PyResult<
         process::exit(1);
     };
 
-    let dir = file_path.parent().unwrap().to_str().unwrap().to_string();
+    let dir = file_path.parent().unwrap().to_str().unwrap().to_owned();
     let sys_path = vm.get_attribute(vm.sys_module.clone(), "path").unwrap();
     vm.call_method(&sys_path, "insert", vec![vm.new_int(0), vm.new_str(dir)])?;
 
     match util::read_file(&file_path) {
         Ok(source) => {
-            _run_string(vm, scope, &source, file_path.to_str().unwrap().to_string())?;
+            _run_string(vm, scope, &source, file_path.to_str().unwrap().to_owned())?;
         }
         Err(err) => {
             error!(
@@ -431,139 +461,3 @@ fn test_run_script() {
     let r = run_script(&vm, vm.new_scope_with_builtins(), "tests/snippets/dir_main");
     assert!(r.is_ok());
 }
-
-enum ShellExecResult {
-    Ok,
-    PyErr(PyObjectRef),
-    Continue,
-}
-
-fn shell_exec(vm: &VirtualMachine, source: &str, scope: Scope) -> ShellExecResult {
-    match vm.compile(source, compile::Mode::Single, "<stdin>".to_string()) {
-        Ok(code) => {
-            match vm.run_code_obj(code, scope.clone()) {
-                Ok(value) => {
-                    // Save non-None values as "_"
-                    if !vm.is_none(&value) {
-                        let key = "_";
-                        scope.globals.set_item(key, value, vm).unwrap();
-                    }
-                    ShellExecResult::Ok
-                }
-                Err(err) => ShellExecResult::PyErr(err),
-            }
-        }
-        Err(CompileError {
-            error: CompileErrorType::Parse(ParseErrorType::EOF),
-            ..
-        }) => ShellExecResult::Continue,
-        Err(err) => ShellExecResult::PyErr(vm.new_syntax_error(&err)),
-    }
-}
-
-fn run_shell(vm: &VirtualMachine, scope: Scope) -> PyResult<()> {
-    use rustyline::{error::ReadlineError, Editor};
-
-    println!(
-        "Welcome to the magnificent Rust Python {} interpreter \u{1f631} \u{1f596}",
-        crate_version!()
-    );
-
-    // Read a single line:
-    let mut input = String::new();
-    let mut repl = Editor::<()>::new();
-
-    // Retrieve a `history_path_str` dependent on the OS
-    let repl_history_path = match dirs::config_dir() {
-        Some(mut path) => {
-            path.push("rustpython");
-            path.push("repl_history.txt");
-            path
-        }
-        None => ".repl_history.txt".into(),
-    };
-
-    if !repl_history_path.exists() {
-        if let Some(parent) = repl_history_path.parent() {
-            std::fs::create_dir_all(parent).unwrap();
-        }
-    }
-
-    if repl.load_history(&repl_history_path).is_err() {
-        println!("No previous history.");
-    }
-
-    let mut continuing = false;
-
-    loop {
-        let prompt_name = if continuing { "ps2" } else { "ps1" };
-        let prompt = vm
-            .get_attribute(vm.sys_module.clone(), prompt_name)
-            .and_then(|prompt| vm.to_str(&prompt));
-        let prompt = match prompt {
-            Ok(ref s) => s.as_str(),
-            Err(_) => "",
-        };
-        let result = match repl.readline(prompt) {
-            Ok(line) => {
-                debug!("You entered {:?}", line);
-
-                repl.add_history_entry(line.trim_end());
-
-                let stop_continuing = line.is_empty();
-
-                if input.is_empty() {
-                    input = line;
-                } else {
-                    input.push_str(&line);
-                }
-                input.push_str("\n");
-
-                if continuing {
-                    if stop_continuing {
-                        continuing = false;
-                    } else {
-                        continue;
-                    }
-                }
-
-                match shell_exec(vm, &input, scope.clone()) {
-                    ShellExecResult::Ok => {
-                        input.clear();
-                        Ok(())
-                    }
-                    ShellExecResult::Continue => {
-                        continuing = true;
-                        Ok(())
-                    }
-                    ShellExecResult::PyErr(err) => {
-                        input.clear();
-                        Err(err)
-                    }
-                }
-            }
-            Err(ReadlineError::Interrupted) => {
-                continuing = false;
-                input.clear();
-                let keyboard_interrupt = vm
-                    .new_empty_exception(vm.ctx.exceptions.keyboard_interrupt.clone())
-                    .unwrap();
-                Err(keyboard_interrupt)
-            }
-            Err(ReadlineError::Eof) => {
-                break;
-            }
-            Err(err) => {
-                eprintln!("Readline error: {:?}", err);
-                break;
-            }
-        };
-
-        if let Err(exc) = result {
-            print_exception(vm, &exc);
-        }
-    }
-    repl.save_history(&repl_history_path).unwrap();
-
-    Ok(())
-}
