@@ -51,3 +51,12 @@ def g():
 a, b = g()
 assert a == 1337
 assert b == 42
+
+# Variable annotations:
+a: bool
+b: bool = False
+
+assert a == 1337
+assert b == False
+
+assert __annotations__['a'] == bool
