@@ -14,12 +14,12 @@ assert not 0.0
 
 assert not None
 
-assert bool() == False
-assert bool(1) == True
-assert bool({}) == False
+assert bool() is False
+assert bool(1) is True
+assert bool({}) is False
 
-assert bool(NotImplemented) == True
-assert bool(...) == True
+assert bool(NotImplemented) is True
+assert bool(...) is True
 
 if not 1:
     raise BaseException
@@ -94,6 +94,7 @@ assert bool({"key": "value"}) is True
 assert bool([1]) is True
 assert bool(set([1,2])) is True
 
+assert repr(True) == "True"
 
 # Check __len__ work
 class TestMagicMethodLenZero:
@@ -105,8 +106,8 @@ class TestMagicMethodLenOne:
         return 1
 
 
-assert bool(TestMagicMethodLenZero()) == False
-assert bool(TestMagicMethodLenOne()) == True
+assert bool(TestMagicMethodLenZero()) is False
+assert bool(TestMagicMethodLenOne()) is True
 
 
 # check __len__ and __bool__
