@@ -57,6 +57,13 @@ assert_raises(TypeError, lambda: divmod(2, complex(2, -3)))
 assert complex(1) ** 2 == 1
 assert 2 ** complex(2) == 4
 
+# __pos__
+
+assert +complex(0, 1) == complex(0, 1)
+assert +complex(1, 0) == complex(1, 0)
+assert +complex(1, -1) == complex(1, -1)
+assert +complex(0, 0) == complex(0, 0)
+
 # __neg__
 
 assert -complex(1, -1) == complex(-1, 1)
@@ -129,4 +136,31 @@ assert '(1-1j)' == repr(1-1j)
 
 # __getnewargs__
 assert (3 + 5j).__getnewargs__() == (3.0, 5.0)
-assert (5j).__getnewargs__() == (0.0, 5.0)
\ No newline at end of file
+assert (5j).__getnewargs__() == (0.0, 5.0)
+
+
+class Complex():
+    def __init__(self, real, imag):
+        self.real = real
+        self.imag = imag
+
+    def __repr__(self):
+        return "Com" + str((self.real, self.imag))
+
+    def __sub__(self, other):
+        return Complex(self.real - other, self.imag)
+
+    def __rsub__(self, other):
+        return Complex(other - self.real, -self.imag)
+
+    def __eq__(self, other):
+        return self.real == other.real and self.imag == other.imag
+
+assert Complex(4, 5) - 3 == Complex(1, 5)
+assert 7 - Complex(4, 5) == Complex(3, -5)
+
+assert complex("5+2j") == 5 + 2j
+assert complex("5-2j") == 5 - 2j
+assert complex("-2j") == -2j
+assert_raises(TypeError, lambda: complex("5+2j", 1))
+assert_raises(ValueError, lambda: complex("abc"))
