@@ -1,12 +1,12 @@
-from testutils import assertRaises
+from testutils import assert_raises
 
 assert '__builtins__' in globals()
 # assert type(__builtins__).__name__ == 'module'
-with assertRaises(AttributeError):
+with assert_raises(AttributeError):
     __builtins__.__builtins__
 
 __builtins__.x = 'new'
-assert x == 'new'
+assert x == 'new'  # noqa: F821
 
 exec('assert "__builtins__" in globals()', dict())
 exec('assert __builtins__ == 7', {'__builtins__': 7})
@@ -17,12 +17,12 @@ namespace = {}
 exec('', namespace)
 assert namespace['__builtins__'] == __builtins__.__dict__
 
-# with assertRaises(NameError):
+# with assert_raises(NameError):
 #     exec('print(__builtins__)', {'__builtins__': {}})
 
 # __builtins__ is deletable but names are alive
 del __builtins__
-with assertRaises(NameError):
-    __builtins__
+with assert_raises(NameError):
+    __builtins__  # noqa: F821
 
 assert print
