@@ -33,6 +33,10 @@ class Bar:
         assert __class__ is Bar
         return self.x
 
+    def doc_func(self):
+        "doc string"
+        pass
+
     @classmethod
     def fubar(cls, x):
         assert __class__ is cls
@@ -48,6 +52,8 @@ class Bar:
 assert Bar.__doc__ == " W00t "
 
 bar = Bar(42)
+assert bar.get_x.__doc__ == None
+assert bar.doc_func.__doc__ == "doc string"
 
 bar.fubar(2)
 Bar.fubar(2)
@@ -163,7 +169,9 @@ class T5(int):
 
 assert str(super(int, T5(5))) == "<super: <class 'int'>, <T5 object>>"
 
-#assert str(super(type, None)) == "<super: <class 'type'>, NULL>"
+assert str(super(type, None)) == "<super: <class 'type'>, NULL>"
+
+assert str(super(int).__get__(T5(5))) == "<super: <class 'int'>, <T5 object>>"
 
 a = 1
 class A:
@@ -174,6 +182,16 @@ class A:
     assert a == 2
 A.b()
 
+class A:
+    pass
+
+assert A.__doc__ == None
+
+class B:
+    "Docstring"
+
+assert B.__doc__ == "Docstring"
+
 # TODO: uncomment once free vars/cells are working
 # The symboltable sees that b() is referring to a in the nested scope,
 # so it marks it as non local. When it's executed, it walks up the scopes
@@ -189,3 +207,49 @@ A.b()
 #         assert a == 3
 #     A.b()
 # nested_scope()
+
+
+
+# Multiple inheritance and mro tests.
+class A():
+    def f(self):
+        return 'a'
+
+class B(A):
+    def f(self):
+        return 'b' + super().f()
+
+class C(A):
+    def f(self):
+        return 'c' + super().f()
+
+class D(B, C):
+    def f(self):
+        return 'd' + super().f()
+
+assert D().f() == 'dbca', "Mro resolution using super failed."
+
+
+
+class A():
+    pass
+try:
+    class B(A, A):
+        pass
+except TypeError:
+    pass
+else:
+    assert False, "Managed to create a class with duplicate base classes."
+
+
+class A():
+    pass
+class B(A):
+    pass
+try:
+    class C(A, B):
+        pass
+except TypeError:
+    pass
+else:
+    assert False, "Managed to create a class without local type precedence."
