@@ -15,6 +15,8 @@ exc = KeyError('message')
 assert str(exc) == "'message'"
 assert round_trip_repr(exc)
 
+assert LookupError.__str__(exc) == "message"
+
 exc = KeyError('message', 'another message')
 assert str(exc) == "('message', 'another message')"
 assert round_trip_repr(exc)
@@ -51,3 +53,23 @@ assert exc.name == 'name'
 assert exc.path == 'path'
 assert exc.msg == 'hello'
 assert exc.args == ('hello',)
+
+
+class NewException(Exception):
+
+	def __init__(self, value):
+		self.value = value
+
+
+try:
+	raise NewException("test")
+except NewException as e:
+	assert e.value == "test"
+
+
+exc = SyntaxError('msg', 1, 2, 3, 4, 5)
+assert exc.msg == 'msg'
+assert exc.filename is None
+assert exc.lineno is None
+assert exc.offset is None
+assert exc.text is None
