@@ -13,6 +13,7 @@ assert foo.__doc__ == "test"
 assert foo.__name__ == "foo"
 assert foo.__qualname__ == "foo"
 assert foo.__module__ == "function"
+assert foo.__globals__ is globals()
 
 def my_func(a,):
     return a+2
@@ -95,3 +96,8 @@ assert f8() == 10
 
 with assert_raises(SyntaxError):
     exec('print(keyword=10, 20)')
+
+def f9():
+    pass
+
+assert f9.__doc__ == None
