@@ -17,3 +17,12 @@ assert MyObject().__lt__(MyObject()) == NotImplemented
 assert MyObject().__le__(MyObject()) == NotImplemented
 assert MyObject().__gt__(MyObject()) == NotImplemented
 assert MyObject().__ge__(MyObject()) == NotImplemented
+
+obj = MyObject()
+
+assert obj.__eq__(obj) is True
+assert obj.__ne__(obj) is False
+
+assert not hasattr(obj, 'a')
+obj.__dict__ = {'a': 1}
+assert obj.a == 1
