@@ -63,27 +63,30 @@ assert os.fspath(b"Testing") == b"Testing"
 assert_raises(TypeError, lambda: os.fspath([1,2,3]))
 
 class TestWithTempDir():
-	def __enter__(self):
-		if os.name == "nt":
-			base_folder = os.environ["TEMP"]
-		else:
-			base_folder = "/tmp"
-		name = os.path.join(base_folder, "rustpython_test_os_" + str(int(time.time())))
-		os.mkdir(name)
-		self.name = name
-		return name
+    def __enter__(self):
+        if os.name == "nt":
+            base_folder = os.environ["TEMP"]
+        else:
+            base_folder = "/tmp"
 
-	def __exit__(self, exc_type, exc_val, exc_tb):
-		# TODO: Delete temp dir
-		pass
+        name = os.path.join(base_folder, "rustpython_test_os_" + str(int(time.time())))
 
+        while os.path.isdir(name):
+            name = name + "_"
+
+        os.mkdir(name)
+        self.name = name
+        return name
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        pass
 
 class TestWithTempCurrentDir():
-	def __enter__(self):
-		self.prev_cwd = os.getcwd()
+    def __enter__(self):
+        self.prev_cwd = os.getcwd()
 
-	def __exit__(self, exc_type, exc_val, exc_tb):
-		os.chdir(self.prev_cwd)
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        os.chdir(self.prev_cwd)
 
 
 FILE_NAME = "test1"
@@ -122,6 +125,17 @@ with TestWithTempDir() as tmpdir:
 	assert os.read(fd, len(CONTENT2) + len(CONTENT3)) == CONTENT2 + CONTENT3
 	os.close(fd)
 
+	assert not os.isatty(fd)
+
+  # TODO: get os.lseek working on windows
+	if os.name != 'nt':
+		fd = os.open(fname3, 0)
+		assert os.read(fd, len(CONTENT2)) == CONTENT2
+		assert os.read(fd, len(CONTENT3)) == CONTENT3
+		os.lseek(fd, len(CONTENT2), os.SEEK_SET)
+		assert os.read(fd, len(CONTENT3)) == CONTENT3
+		os.close(fd)
+
 	os.rename(fname3, fname)
 	assert os.path.exists(fname3) == False
 	assert os.path.exists(fname) == True
@@ -192,6 +206,8 @@ with TestWithTempDir() as tmpdir:
 	assert stat_res.st_ctime > 1557500000
 	assert stat_res.st_mtime > 1557500000
 
+	bytes_stats_res = os.stat(fname.encode())
+
 	stat_file2 = os.stat(fname2)
 	print(stat_file2.st_ctime)
 	assert stat_file2.st_ctime > stat_res.st_ctime
@@ -250,8 +266,8 @@ with TestWithTempDir() as tmpdir:
 
 	with TestWithTempCurrentDir():
 		os.chdir(tmpdir)
-		assert os.getcwd() == os.path.realpath(tmpdir)
-		os.path.exists(FILE_NAME)
+		assert os.path.realpath(os.getcwd()) == os.path.realpath(tmpdir)
+		assert os.path.exists(FILE_NAME)
 
 # supports
 assert isinstance(os.supports_fd, set)
@@ -277,6 +293,8 @@ if "win" not in sys.platform:
         assert_raises(PermissionError, lambda: os.setpgid(os.getpid(), 42))
         assert_raises(PermissionError, lambda: os.setuid(42))
         assert_raises(PermissionError, lambda: os.seteuid(42))
+        assert_raises(PermissionError, lambda: os.setreuid(42, 42))
+        assert_raises(PermissionError, lambda: os.setresuid(42, 42, 42))
 
     # pty
     a, b = os.openpty()
@@ -286,3 +304,115 @@ if "win" not in sys.platform:
     assert_raises(OSError, lambda: os.ttyname(9999))
     os.close(b)
     os.close(a)
+
+    # os.get_blocking, os.set_blocking
+    # TODO: windows support should be added for below functions
+    # os.pipe,
+    # os.set_inheritable, os.get_inheritable,
+    rfd, wfd = os.pipe()
+    try:
+        os.write(wfd, CONTENT2)
+        assert os.read(rfd, len(CONTENT2)) == CONTENT2
+        assert not os.get_inheritable(rfd)
+        assert not os.get_inheritable(wfd)
+        os.set_inheritable(rfd, True)
+        os.set_inheritable(wfd, True)
+        assert os.get_inheritable(rfd)
+        assert os.get_inheritable(wfd)
+        os.set_inheritable(rfd, True)
+        os.set_inheritable(wfd, True)
+        os.set_inheritable(rfd, True)
+        os.set_inheritable(wfd, True)
+        assert os.get_inheritable(rfd)
+        assert os.get_inheritable(wfd)
+
+        assert os.get_blocking(rfd)
+        assert os.get_blocking(wfd)
+        os.set_blocking(rfd, False)
+        os.set_blocking(wfd, False)
+        assert not os.get_blocking(rfd)
+        assert not os.get_blocking(wfd)
+        os.set_blocking(rfd, True)
+        os.set_blocking(wfd, True)
+        os.set_blocking(rfd, True)
+        os.set_blocking(wfd, True)
+        assert os.get_blocking(rfd)
+        assert os.get_blocking(wfd)
+    finally:
+        os.close(rfd)
+        os.close(wfd)
+
+# os.pipe2
+if sys.platform.startswith('linux') or sys.platform.startswith('freebsd'):
+    rfd, wfd = os.pipe2(0)
+    try:
+        os.write(wfd, CONTENT2)
+        assert os.read(rfd, len(CONTENT2)) == CONTENT2
+        assert os.get_inheritable(rfd)
+        assert os.get_inheritable(wfd)
+        assert os.get_blocking(rfd)
+        assert os.get_blocking(wfd)
+    finally:
+        os.close(rfd)
+        os.close(wfd)
+    rfd, wfd = os.pipe2(os.O_CLOEXEC | os.O_NONBLOCK)
+    try:
+        os.write(wfd, CONTENT2)
+        assert os.read(rfd, len(CONTENT2)) == CONTENT2
+        assert not os.get_inheritable(rfd)
+        assert not os.get_inheritable(wfd)
+        assert not os.get_blocking(rfd)
+        assert not os.get_blocking(wfd)
+    finally:
+        os.close(rfd)
+        os.close(wfd)
+
+
+with TestWithTempDir() as tmpdir:
+    for i in range(0, 4):
+        file_name = os.path.join(tmpdir, 'file' + str(i))
+        with open(file_name, 'w') as f:
+            f.write('test')
+
+    expected_files = ['file0', 'file1', 'file2', 'file3']
+
+    dir_iter = os.scandir(tmpdir)
+    collected_files = [dir_entry.name for dir_entry in dir_iter]
+
+    assert set(collected_files) == set(expected_files)
+
+    with assert_raises(StopIteration):
+        next(dir_iter)
+
+    dir_iter.close()
+
+    expected_files_bytes = [(file.encode(), os.path.join(tmpdir, file).encode()) for file in expected_files]
+
+    dir_iter_bytes = os.scandir(tmpdir.encode())
+    collected_files_bytes = [(dir_entry.name, dir_entry.path) for dir_entry in dir_iter_bytes]
+
+    assert set(collected_files_bytes) == set(expected_files_bytes)
+
+    dir_iter_bytes.close()
+
+    collected_files = os.listdir(tmpdir)
+    assert set(collected_files) == set(expected_files)
+
+    collected_files = os.listdir(tmpdir.encode())
+    assert set(collected_files) == set([file.encode() for file in expected_files ])
+
+    with TestWithTempCurrentDir():
+        os.chdir(tmpdir)
+        with os.scandir() as dir_iter:
+            collected_files = [dir_entry.name for dir_entry in dir_iter]
+            assert set(collected_files) == set(expected_files)
+
+# system()
+if "win" not in sys.platform:
+    assert os.system('ls') == 0
+    assert os.system('{') != 0
+
+    for arg in [None, 1, 1.0, TabError]:
+        assert_raises(TypeError, os.system, arg)
+
+
