@@ -1,10 +1,10 @@
 import types
 
-from testutils import assertRaises
+from testutils import assert_raises
 
 ns = types.SimpleNamespace(a=2, b='Rust')
 
 assert ns.a == 2
 assert ns.b == "Rust"
-with assertRaises(AttributeError):
+with assert_raises(AttributeError):
     _ = ns.c
