@@ -1,3 +1,8 @@
+try:
+    import gc
+except ImportError:
+    gc = None
+
 assert type(type) is type
 assert type(object) is type
 assert type(object()) is object
@@ -43,16 +48,54 @@ assert B.__subclasses__() == [D]
 assert C.__subclasses__() == [D]
 assert D.__subclasses__() == []
 
+assert D.__bases__ == (B, C)
+assert A.__bases__ == (object,)
+assert B.__bases__ == (A,)
+
+
 del D
 
-try: # gc sweep is needed here for CPython...
-    import gc; gc.collect()
-except: # ...while RustPython doesn't have `gc` yet.
-    pass
+if gc:
+    # gc sweep is needed here for CPython...
+    gc.collect()
+    # ...while RustPython doesn't have `gc` yet. 
 
-assert B.__subclasses__() == []
-assert C.__subclasses__() == []
+if gc:
+    # D.__new__ is a method bound to the D type, so just deleting D
+    # from globals won't actually invalidate the weak reference that
+    # subclasses holds. TODO: implement a proper tracing gc
+    assert B.__subclasses__() == []
+    assert C.__subclasses__() == []
 
 assert type in object.__subclasses__()
 
 assert cls.__name__ == 'Cls'
+
+# mro
+assert int.mro() == [int, object]
+assert bool.mro() == [bool, int, object]
+assert object.mro() == [object]
+
+class A:
+    pass
+
+class B(A):
+    pass
+
+assert A.mro() == [A, object]
+assert B.mro() == [B, A, object]
+
+class AA:
+    pass
+
+class BB(AA):
+    pass
+
+class C(B, BB):
+    pass
+
+assert C.mro() == [C, B, A, BB, AA, object]
+
+
+assert type(Exception.args).__name__ == 'getset_descriptor'
+assert type(None).__bool__(None) is False
